==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/model/query/SbZsQuery.java <==
package cn.gtmap.landtax.model.query;

import cn.gtmap.landtax.entity.SSjGtbd;

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 税务国土通过djh关联
 * @author yang
 * @version V1.0, 14-7-7
 */
public class SbZsQuery {
    public static final String ZCLX_QY = "企业";
    public static final String ZCLX_GR = "个人";

    private String ydqcId;
    private String year;
    private String jdlx;  // 节点类型
    private String glbm;
    private String nsrmc;
    private String sssq; // 所属属期
    private String zclx; // 企业或个人
    private String qxdm; // 区县代码，过滤行政区用
    private String zgkgDm; // 主管税务机关代码

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getJdlx() {
        return jdlx;
    }

    public void setJdlx(String jdlx) {
        this.jdlx = jdlx;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getYdqcId() {
        return ydqcId;
    }

    public void setYdqcId(String ydqcId) {
        this.ydqcId = ydqcId;
    }

    public String getSssq() {
        return sssq;
    }

    public void setSssq(String sssq) {
        this.sssq = sssq;
    }

    public String getZclx() {
        return zclx;
    }

    public void setZclx(String zclx) {
        this.zclx = zclx;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/SbZsQuery.java <==
package cn.gtmap.landtax.model.query;

import cn.gtmap.landtax.entity.SSjGtbd;

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 税务国土通过djh关联
 * @author yang
 * @version V1.0, 14-7-7
 */
public class SbZsQuery {
    public static final String ZCLX_QY = "企业";
    public static final String ZCLX_GR = "个人";

    private String ydqcId;
    private String year;
    private String jdlx;  // 节点类型
    private String glbm;
    private String nsrmc;
    private String sssq; // 所属属期
    private String zclx; // 企业或个人
    private String qxdm; // 区县代码，过滤行政区用
    private String zgkgDm; // 主管税务机关代码
    private String nsrsbh; //纳税人识别号

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }
    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getJdlx() {
        return jdlx;
    }

    public void setJdlx(String jdlx) {
        this.jdlx = jdlx;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getYdqcId() {
        return ydqcId;
    }

    public void setYdqcId(String ydqcId) {
        this.ydqcId = ydqcId;
    }

    public String getSssq() {
        return sssq;
    }

    public void setSssq(String sssq) {
        this.sssq = sssq;
    }

    public String getZclx() {
        return zclx;
    }

    public void setZclx(String zclx) {
        this.zclx = zclx;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }
}
